pub enum ScopeExecutionError {
Explanation(ExplanationError),
Search(SearchError),
NoReadableDocuments {
reasons: Vec<String>,
},
}Expand description
Query failures independent of catalog resolution and source I/O.
Variants
Explanation(ExplanationError)
The explanation request is invalid.
Search(SearchError)
The search request or matcher is invalid.
NoReadableDocuments
None of the supplied snapshots contains readable explanation content.